==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/userdefinedscreenservice_001/UserDefinedScreenService.java <==

package net.datastream.schemas.mp_entities.userdefinedscreenservice_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERDEFINEDSCREENFIELDVALUELIST;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENNAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSERVICEACTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENFIELDVALUELIST"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userdefinedscreenname",
    "userdefinedserviceaction",
    "userdefinedscreenfieldvaluelist",
    "createddate",
    "createdby",
    "dateupdated",
    "updatedby"
})
@XmlRootElement(name = "UserDefinedScreenService")
public class UserDefinedScreenService {

    @XmlElement(name = "USERDEFINEDSCREENNAME", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String userdefinedscreenname;
    @XmlElement(name = "USERDEFINEDSERVICEACTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String userdefinedserviceaction;
    @XmlElement(name = "USERDEFINEDSCREENFIELDVALUELIST", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERDEFINEDSCREENFIELDVALUELIST userdefinedscreenfieldvaluelist;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété userdefinedscreenname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERDEFINEDSCREENNAME() {
        return userdefinedscreenname;
    }

    /**
     * Définit la valeur de la propriété userdefinedscreenname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERDEFINEDSCREENNAME(String value) {
        this.userdefinedscreenname = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedserviceaction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERDEFINEDSERVICEACTION() {
        return userdefinedserviceaction;
    }

    /**
     * Définit la valeur de la propriété userdefinedserviceaction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERDEFINEDSERVICEACTION(String value) {
        this.userdefinedserviceaction = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedscreenfieldvaluelist.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDSCREENFIELDVALUELIST }
     *     
     */
    public USERDEFINEDSCREENFIELDVALUELIST getUSERDEFINEDSCREENFIELDVALUELIST() {
        return userdefinedscreenfieldvaluelist;
    }

    /**
     * Définit la valeur de la propriété userdefinedscreenfieldvaluelist.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDSCREENFIELDVALUELIST }
     *     
     */
    public void setUSERDEFINEDSCREENFIELDVALUELIST(USERDEFINEDSCREENFIELDVALUELIST value) {
        this.userdefinedscreenfieldvaluelist = value;
    }

    /**
     * Obtient la valeur de la propriété createddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Définit la valeur de la propriété createddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Obtient la valeur de la propriété createdby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Définit la valeur de la propriété createdby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Obtient la valeur de la propriété dateupdated.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Définit la valeur de la propriété dateupdated.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

    /**
     * Obtient la valeur de la propriété updatedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Définit la valeur de la propriété updatedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/userdefinedscreenservice_001/UserDefinedScreenService.java <==

package net.datastream.schemas.mp_entities.userdefinedscreenservice_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERDEFINEDSCREENFIELDVALUELIST;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENNAME"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSERVICEACTION"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDSCREENFIELDVALUELIST"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "userdefinedscreenname",
    "userdefinedserviceaction",
    "userdefinedscreenfieldvaluelist",
    "createddate",
    "createdby",
    "dateupdated",
    "updatedby"
})
@XmlRootElement(name = "UserDefinedScreenService")
public class UserDefinedScreenService {

    @XmlElement(name = "USERDEFINEDSCREENNAME", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String userdefinedscreenname;
    @XmlElement(name = "USERDEFINEDSERVICEACTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String userdefinedserviceaction;
    @XmlElement(name = "USERDEFINEDSCREENFIELDVALUELIST", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERDEFINEDSCREENFIELDVALUELIST userdefinedscreenfieldvaluelist;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the userdefinedscreenname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERDEFINEDSCREENNAME() {
        return userdefinedscreenname;
    }

    /**
     * Sets the value of the userdefinedscreenname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERDEFINEDSCREENNAME(String value) {
        this.userdefinedscreenname = value;
    }

    /**
     * Gets the value of the userdefinedserviceaction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERDEFINEDSERVICEACTION() {
        return userdefinedserviceaction;
    }

    /**
     * Sets the value of the userdefinedserviceaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERDEFINEDSERVICEACTION(String value) {
        this.userdefinedserviceaction = value;
    }

    /**
     * Gets the value of the userdefinedscreenfieldvaluelist property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDSCREENFIELDVALUELIST }
     *     
     */
    public USERDEFINEDSCREENFIELDVALUELIST getUSERDEFINEDSCREENFIELDVALUELIST() {
        return userdefinedscreenfieldvaluelist;
    }

    /**
     * Sets the value of the userdefinedscreenfieldvaluelist property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDSCREENFIELDVALUELIST }
     *     
     */
    public void setUSERDEFINEDSCREENFIELDVALUELIST(USERDEFINEDSCREENFIELDVALUELIST value) {
        this.userdefinedscreenfieldvaluelist = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the dateupdated property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Sets the value of the dateupdated property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

    /**
     * Gets the value of the updatedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Sets the value of the updatedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
